JBoss Portal SVN: r9276 - branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model.
by portal-commits@lists.jboss.org
Author: julien(a)jboss.com
Date: 2007-12-04 06:06:29 -0500 (Tue, 04 Dec 2007)
New Revision: 9276
Modified:
branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIContextImpl.java
Log:
more convenient to use AssertionError than IllegalArgumentException
Modified: branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIContextImpl.java
===================================================================
--- branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIContextImpl.java 2007-12-04 11:01:27 UTC (rev 9275)
+++ branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIContextImpl.java 2007-12-04 11:06:29 UTC (rev 9276)
@@ -177,6 +177,8 @@
private UIObjectImpl createObject(StructuralObject state)
{
Class type = state.getState().getType();
+
+ //
if(type == UIPortal.class)
{
return new UIPortalImpl(this, state);
@@ -195,7 +197,7 @@
}
else
{
- throw new IllegalArgumentException();
+ throw new AssertionError();
}
}
18 years, 7 months
JBoss Portal SVN: r9275 - branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model.
by portal-commits@lists.jboss.org
Author: julien(a)jboss.com
Date: 2007-12-04 06:01:27 -0500 (Tue, 04 Dec 2007)
New Revision: 9275
Modified:
branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIContextImpl.java
branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIPageImpl.java
branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIPortalImpl.java
Log:
simplify isAllowedAsChild implementation
Modified: branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIContextImpl.java
===================================================================
--- branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIContextImpl.java 2007-12-04 10:59:41 UTC (rev 9274)
+++ branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIContextImpl.java 2007-12-04 11:01:27 UTC (rev 9275)
@@ -201,14 +201,7 @@
protected <T extends UIObject> boolean isAllowedAsChild(Class<T> type)
{
- boolean isAllowedAsChild = false;
-
- if(type == UIPortal.class)
- {
- isAllowedAsChild = true;
- }
-
- return isAllowedAsChild;
+ return type == UIPortal.class;
}
protected void fireEvent(ModelEvent event)
Modified: branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIPageImpl.java
===================================================================
--- branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIPageImpl.java 2007-12-04 10:59:41 UTC (rev 9274)
+++ branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIPageImpl.java 2007-12-04 11:01:27 UTC (rev 9275)
@@ -43,17 +43,6 @@
protected <T extends UIObject> boolean isAllowedAsChild(Class<T> type)
{
- boolean isAllowedAsChild = false;
-
- if(
- type == UIPage.class ||
- type == UIContainer.class ||
- type == UIWindow.class
- )
- {
- isAllowedAsChild = true;
- }
-
- return isAllowedAsChild;
+ return type == UIPage.class || type == UIContainer.class || type == UIWindow.class;
}
}
Modified: branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIPortalImpl.java
===================================================================
--- branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIPortalImpl.java 2007-12-04 10:59:41 UTC (rev 9274)
+++ branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIPortalImpl.java 2007-12-04 11:01:27 UTC (rev 9275)
@@ -42,13 +42,6 @@
protected <T extends UIObject> boolean isAllowedAsChild(Class<T> type)
{
- boolean isAllowedAsChild = false;
-
- if(type == UIPage.class)
- {
- isAllowedAsChild = true;
- }
-
- return isAllowedAsChild;
+ return type == UIPage.class;
}
}
18 years, 7 months
JBoss Portal SVN: r9274 - in branches/presentation/presentation/src/main/org/jboss/portal/presentation: model and 2 other directories.
by portal-commits@lists.jboss.org
Author: julien(a)jboss.com
Date: 2007-12-04 05:59:41 -0500 (Tue, 04 Dec 2007)
New Revision: 9274
Modified:
branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIContextImpl.java
branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIObjectImpl.java
branches/presentation/presentation/src/main/org/jboss/portal/presentation/model/UIObject.java
branches/presentation/presentation/src/main/org/jboss/portal/presentation/test/model/ModelTestCase.java
branches/presentation/presentation/src/main/org/jboss/portal/presentation/test/model/state/structural/MockModel.java
branches/presentation/presentation/src/main/org/jboss/portal/presentation/test/model/state/structural/MockObject.java
branches/presentation/presentation/src/main/org/jboss/portal/presentation/test/model/state/structural/MockObjectImpl.java
Log:
early impl of createChild
Modified: branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIContextImpl.java
===================================================================
--- branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIObjectImpl.java 2007-12-04 10:59:39 UTC (rev 9273)
+++ branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIObjectImpl.java 2007-12-04 10:59:41 UTC (rev 9274)
@@ -33,6 +33,7 @@
import java.io.Serializable;
import java.util.ArrayList;
+import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
@@ -55,7 +56,7 @@
private UIObjectImpl parent;
/** This is used to assist with data needed during lazy loading, other state related data etc... */
- StructuralObject structuralObject;
+ private StructuralObject structuralObject;
public UIObjectImpl(UIContextImpl context, StructuralObject object)
{
@@ -238,7 +239,7 @@
if (parent == null)
{
StructuralObject parentStructuralState = context.structuralStateContext.loadParent(structuralObject);
- parent = context.loadObject(parentStructuralState);
+ parent = context.updateUniverse(parentStructuralState);
}
//
@@ -255,14 +256,33 @@
ArrayList<UIObject> tmp = new ArrayList<UIObject>();
for (StructuralObject structuralChild : context.structuralStateContext.loadChildren(structuralObject))
{
- UIObjectImpl child = context.loadObject(structuralChild);
+ UIObjectImpl child = context.updateUniverse(structuralChild);
tmp.add(child);
}
- return tmp;
+ children = tmp;
}
return children;
}
-
+
+ private static final Map<String, String> EMPTY_STATE = Collections.emptyMap();
+
+ public <T extends UIObject> T createChild(String name, Class<T> type) throws IllegalArgumentException
+ {
+ String id = context.structuralStateContext.create(context.listener, structuralObject, type, name, EMPTY_STATE);
+
+ //
+ return type.cast(context.getFromUniverse(id, false));
+ }
+
+ void update(StructuralObject object)
+ {
+ structuralObject = object;
+ parent = null;
+ children = null;
+ }
+
+ protected abstract <T extends UIObject> boolean isAllowedAsChild(Class<T> type);
+
/**
*
*/
@@ -296,7 +316,6 @@
// throw new UnsupportedOperationException("todo");
// }
- protected abstract <T extends UIObject> boolean isAllowedAsChild(Class<T> type);
/**
@@ -469,5 +488,5 @@
return uiContext;
}
-*/
+*/
}
Modified: branches/presentation/presentation/src/main/org/jboss/portal/presentation/model/UIObject.java
===================================================================
--- branches/presentation/presentation/src/main/org/jboss/portal/presentation/model/UIObject.java 2007-12-04 10:59:39 UTC (rev 9273)
+++ branches/presentation/presentation/src/main/org/jboss/portal/presentation/model/UIObject.java 2007-12-04 10:59:41 UTC (rev 9274)
@@ -71,7 +71,7 @@
* @return the newly created child
* @throws IllegalArgumentException if the name is null, already exists or this kind of object does not accept children of the specified type
*/
-// public <T extends UIObject> T createChild(String name, Class<T> type) throws IllegalArgumentException;
+ public <T extends UIObject> T createChild(String name, Class<T> type) throws IllegalArgumentException;
/**
*
Modified: branches/presentation/presentation/src/main/org/jboss/portal/presentation/test/model/ModelTestCase.java
===================================================================
--- branches/presentation/presentation/src/main/org/jboss/portal/presentation/test/model/ModelTestCase.java 2007-12-04 10:59:39 UTC (rev 9273)
+++ branches/presentation/presentation/src/main/org/jboss/portal/presentation/test/model/ModelTestCase.java 2007-12-04 10:59:41 UTC (rev 9274)
@@ -496,4 +496,19 @@
{
}
}
+
+ public void testCreateChild()
+ {
+ UIContext context = createContext();
+
+ assertNull(context.getChild("foo"));
+
+ UIPortal portal = context.createChild("foo", UIPortal.class);
+
+ assertNotNull(portal);
+
+ assertSame(context, portal.getParent());
+
+ assertSame(portal, context.getChild("foo"));
+ }
}
Modified: branches/presentation/presentation/src/main/org/jboss/portal/presentation/test/model/state/structural/MockModel.java
===================================================================
--- branches/presentation/presentation/src/main/org/jboss/portal/presentation/test/model/state/structural/MockModel.java 2007-12-04 10:59:39 UTC (rev 9273)
+++ branches/presentation/presentation/src/main/org/jboss/portal/presentation/test/model/state/structural/MockModel.java 2007-12-04 10:59:41 UTC (rev 9274)
@@ -22,14 +22,19 @@
******************************************************************************/
package org.jboss.portal.presentation.test.model.state.structural;
+import org.jboss.portal.presentation.model.UIContext;
+import org.jboss.portal.presentation.model.UIObject;
+import org.jboss.portal.presentation.model.UIPage;
+import org.jboss.portal.presentation.model.UIPortal;
+import org.jboss.portal.presentation.model.UIWindow;
import org.jboss.portal.presentation.model.state.NoSuchStateException;
import org.jboss.portal.presentation.model.state.StaleStateException;
import org.jboss.portal.presentation.model.state.StateChangeVetoException;
import org.jboss.portal.presentation.model.state.StateException;
import org.jboss.portal.presentation.model.state.structural.AbstractStructuralStateContext;
import org.jboss.portal.presentation.model.state.structural.StructuralObject;
+import org.jboss.portal.presentation.model.state.structural.StructuralStateChangeListener;
import org.jboss.portal.presentation.model.state.structural.StructuralStateContext;
-import org.jboss.portal.presentation.model.state.structural.StructuralStateChangeListener;
import java.util.ArrayList;
import java.util.HashMap;
@@ -52,6 +57,18 @@
/** . */
private final MockObjectImpl root = createObject(MockObject.Type.CONTEXT, "");
+ /** . */
+ private static final Map<Class<? extends UIObject>, MockObject.Type> map;
+
+ static
+ {
+ map = new HashMap<Class<? extends UIObject>, MockObject.Type>();
+ map.put(UIContext.class, MockObject.Type.CONTEXT);
+ map.put(UIPage.class, MockObject.Type.PAGE);
+ map.put(UIPortal.class, MockObject.Type.PORTAL);
+ map.put(UIWindow.class, MockObject.Type.WINDOW);
+ }
+
public StructuralStateContext getStructuralStateContext()
{
return structuralStateContext;
@@ -127,6 +144,24 @@
}
}
+ public String create(StructuralStateChangeListener listener, StructuralObject parent, Class<? extends UIObject> classType, String name, Map<String, String> properties) throws StateChangeVetoException, StateException, IllegalArgumentException
+ {
+ MockObject mockParent = getValidMockObject(parent);
+
+ //
+ MockObject.Type type = map.get(classType);
+
+ //
+ MockObject mockChild = mockParent.addChild(name, type, properties);
+
+ //
+ listener.update(mockParent.takeSnapshot());
+ listener.update(mockChild.takeSnapshot());
+
+ //
+ return mockChild.getId();
+ }
+
public List<StructuralObject> loadChildren(StructuralObject object)
{
MockObject mockObject = getValidMockObject(object);
Modified: branches/presentation/presentation/src/main/org/jboss/portal/presentation/test/model/state/structural/MockObject.java
===================================================================
--- branches/presentation/presentation/src/main/org/jboss/portal/presentation/test/model/state/structural/MockObject.java 2007-12-04 10:59:39 UTC (rev 9273)
+++ branches/presentation/presentation/src/main/org/jboss/portal/presentation/test/model/state/structural/MockObject.java 2007-12-04 10:59:41 UTC (rev 9274)
@@ -30,6 +30,7 @@
import org.jboss.portal.presentation.model.state.structural.StructuralObject;
import java.util.List;
+import java.util.Map;
import java.util.Set;
/**
@@ -111,6 +112,8 @@
Set<String> getPropertyNames();
+ MockObject addChild(String name, Type type, Map<String, String> state);
+
MockObject addChild(String name, Type type);
MockObject getParent();
Modified: branches/presentation/presentation/src/main/org/jboss/portal/presentation/test/model/state/structural/MockObjectImpl.java
===================================================================
--- branches/presentation/presentation/src/main/org/jboss/portal/presentation/test/model/state/structural/MockObjectImpl.java 2007-12-04 10:59:39 UTC (rev 9273)
+++ branches/presentation/presentation/src/main/org/jboss/portal/presentation/test/model/state/structural/MockObjectImpl.java 2007-12-04 10:59:41 UTC (rev 9274)
@@ -40,6 +40,9 @@
{
/** . */
+ private static final Map<String, String> EMPTY_STATE = Collections.emptyMap();
+
+ /** . */
private final MockObject.Type type;
/** . */
@@ -119,6 +122,16 @@
public MockObject addChild(String name, MockObject.Type type)
{
+ return addChild(name, type, EMPTY_STATE);
+ }
+
+ public Set<String> getPropertyNames()
+ {
+ return propertyValues.keySet();
+ }
+
+ public MockObject addChild(String name, Type type, Map<String, String> state)
+ {
if (name == null)
{
throw new IllegalArgumentException();
@@ -134,6 +147,16 @@
MockObjectImpl child = model.createObject(type, name);
//
+ for (Map.Entry<String, String> entry : state.entrySet())
+ {
+ if (entry.getValue() == null)
+ {
+ throw new IllegalArgumentException();
+ }
+ child.propertyValues.put(entry.getKey(), entry.getValue());
+ }
+
+ //
child.parent = this;
children.put(child.id, child);
version++;
@@ -142,11 +165,6 @@
return child;
}
- public Set<String> getPropertyNames()
- {
- return propertyValues.keySet();
- }
-
public void setPropertyBehavior(String propertyName, UpdateBehavior propertyBehavior)
{
if (propertyName == null)
@@ -216,5 +234,4 @@
// We cannot use it anymore
valid = false;
}
-
}
18 years, 7 months
JBoss Portal SVN: r9273 - in docs/tags/JBoss_Portal_2_6_3: readmeFiles and 2 other directories.
by portal-commits@lists.jboss.org
Author: thomas.heute(a)jboss.com
Date: 2007-12-04 05:59:39 -0500 (Tue, 04 Dec 2007)
New Revision: 9273
Modified:
docs/tags/JBoss_Portal_2_6_3/quickstartuser/en/master.xml
docs/tags/JBoss_Portal_2_6_3/readmeFiles/jboss-portal-bin.README
docs/tags/JBoss_Portal_2_6_3/readmeFiles/jboss-portal-ha-bin.README
docs/tags/JBoss_Portal_2_6_3/readmeFiles/jboss-portal-src.README
docs/tags/JBoss_Portal_2_6_3/referenceGuide/en/master.xml
docs/tags/JBoss_Portal_2_6_3/userGuide/en/master.xml
Log:
Changing version to 2.6.3
Modified: docs/tags/JBoss_Portal_2_6_3/quickstartuser/en/master.xml
===================================================================
--- docs/tags/JBoss_Portal_2_6_3/quickstartuser/en/master.xml 2007-12-04 10:52:33 UTC (rev 9272)
+++ docs/tags/JBoss_Portal_2_6_3/quickstartuser/en/master.xml 2007-12-04 10:59:39 UTC (rev 9273)
@@ -11,9 +11,9 @@
]>
<book lang="en">
<bookinfo>
- <title>JBoss Portal 2.6.3-SNAPSHOT</title>
+ <title>JBoss Portal 2.6.3</title>
<subtitle>Quickstart User Guide</subtitle>
- <releaseinfo>Release 2.6.3-SNAPSHOT</releaseinfo>
+ <releaseinfo>Release 2.6.3</releaseinfo>
<author>
<firstname>Kevin</firstname>
Modified: docs/tags/JBoss_Portal_2_6_3/readmeFiles/jboss-portal-bin.README
===================================================================
--- docs/tags/JBoss_Portal_2_6_3/readmeFiles/jboss-portal-bin.README 2007-12-04 10:52:33 UTC (rev 9272)
+++ docs/tags/JBoss_Portal_2_6_3/readmeFiles/jboss-portal-bin.README 2007-12-04 10:59:39 UTC (rev 9273)
@@ -1,5 +1,5 @@
- JBoss Portal 2.6.3-SNAPSHOT
+ JBoss Portal 2.6.3
LGPL Licensed (See http://www.gnu.org/copyleft/lesser.html for details on the product usage)
JBoss Portal is the next generation open source content management system (CMS) and portal
Modified: docs/tags/JBoss_Portal_2_6_3/readmeFiles/jboss-portal-ha-bin.README
===================================================================
--- docs/tags/JBoss_Portal_2_6_3/readmeFiles/jboss-portal-ha-bin.README 2007-12-04 10:52:33 UTC (rev 9272)
+++ docs/tags/JBoss_Portal_2_6_3/readmeFiles/jboss-portal-ha-bin.README 2007-12-04 10:59:39 UTC (rev 9273)
@@ -1,5 +1,5 @@
- JBoss Portal 2.6.3-SNAPSHOT
+ JBoss Portal 2.6.3
LGPL Licensed (See http://www.gnu.org/copyleft/lesser.html for details on the product usage)
JBoss Portal is the next generation open source content management system (CMS) and portal
Modified: docs/tags/JBoss_Portal_2_6_3/readmeFiles/jboss-portal-src.README
===================================================================
--- docs/tags/JBoss_Portal_2_6_3/readmeFiles/jboss-portal-src.README 2007-12-04 10:52:33 UTC (rev 9272)
+++ docs/tags/JBoss_Portal_2_6_3/readmeFiles/jboss-portal-src.README 2007-12-04 10:59:39 UTC (rev 9273)
@@ -1,5 +1,5 @@
- JBoss Portal 2.6.3-SNAPSHOT
+ JBoss Portal 2.6.3
LGPL Licensed (See http://www.gnu.org/copyleft/lesser.html for details on the product usage)
JBoss Portal is the next generation open source content management system (CMS) and portal
Modified: docs/tags/JBoss_Portal_2_6_3/referenceGuide/en/master.xml
===================================================================
--- docs/tags/JBoss_Portal_2_6_3/referenceGuide/en/master.xml 2007-12-04 10:52:33 UTC (rev 9272)
+++ docs/tags/JBoss_Portal_2_6_3/referenceGuide/en/master.xml 2007-12-04 10:59:39 UTC (rev 9273)
@@ -37,10 +37,10 @@
]>
<book lang="en">
<bookinfo>
- <title>JBoss Portal 2.6.3-SNAPSHOT</title>
+ <title>JBoss Portal 2.6.3</title>
<subtitle>Reference Guide</subtitle>
- <releaseinfo>Release 2.6.3-SNAPSHOT</releaseinfo>
- <releaseinfo>October 2007</releaseinfo>
+ <releaseinfo>Release 2.6.3</releaseinfo>
+ <releaseinfo>December 2007</releaseinfo>
<author>
<firstname>Thomas</firstname>
<surname>Heute</surname>
Modified: docs/tags/JBoss_Portal_2_6_3/userGuide/en/master.xml
===================================================================
--- docs/tags/JBoss_Portal_2_6_3/userGuide/en/master.xml 2007-12-04 10:52:33 UTC (rev 9272)
+++ docs/tags/JBoss_Portal_2_6_3/userGuide/en/master.xml 2007-12-04 10:59:39 UTC (rev 9273)
@@ -13,10 +13,10 @@
]>
<book lang="en">
<bookinfo>
- <title>JBoss Portal 2.6.3-SNAPSHOT</title>
+ <title>JBoss Portal 2.6.3</title>
<subtitle>User Guide</subtitle>
- <releaseinfo>Release 2.6.3-SNAPSHOT "Ninja"</releaseinfo>
- <releaseinfo>October 2007</releaseinfo>
+ <releaseinfo>Release 2.6.3 "Ninja"</releaseinfo>
+ <releaseinfo>December 2007</releaseinfo>
</bookinfo>
<toc/>
<!-- portal overview - marketing stuff --> &overview;
18 years, 7 months
JBoss Portal SVN: r9272 - docs/tags.
by portal-commits@lists.jboss.org
Author: thomas.heute(a)jboss.com
Date: 2007-12-04 05:52:33 -0500 (Tue, 04 Dec 2007)
New Revision: 9272
Added:
docs/tags/JBoss_Portal_2_6_3/
Log:
Tagging doc to 2.6.3
Copied: docs/tags/JBoss_Portal_2_6_3 (from rev 9271, docs/branches/JBoss_Portal_Branch_2_6)
18 years, 7 months
JBoss Portal SVN: r9271 - tags/JBoss_Portal_2_6_3/core-cms/src/bin/portal-cms-sar/portal/cms/conf/default-content/default.
by portal-commits@lists.jboss.org
Author: thomas.heute(a)jboss.com
Date: 2007-12-04 05:50:35 -0500 (Tue, 04 Dec 2007)
New Revision: 9271
Modified:
tags/JBoss_Portal_2_6_3/core-cms/src/bin/portal-cms-sar/portal/cms/conf/default-content/default/index.html
Log:
Remove vertical bar on index page
Modified: tags/JBoss_Portal_2_6_3/core-cms/src/bin/portal-cms-sar/portal/cms/conf/default-content/default/index.html
===================================================================
--- tags/JBoss_Portal_2_6_3/core-cms/src/bin/portal-cms-sar/portal/cms/conf/default-content/default/index.html 2007-12-04 10:03:00 UTC (rev 9270)
+++ tags/JBoss_Portal_2_6_3/core-cms/src/bin/portal-cms-sar/portal/cms/conf/default-content/default/index.html 2007-12-04 10:50:35 UTC (rev 9271)
@@ -9,13 +9,10 @@
}
#welcomegreybox {
- padding: 15px;
margin-bottom: 30px;
}
#welcomegreyboxTD {
- border-left: 1px solid #d5d5d5;
- padding-left: 15px;
}
#welcomegreybox h3 {
18 years, 7 months
JBoss Portal SVN: r9270 - in tags/JBoss_Portal_2_6_3: server/src/main/org/jboss/portal/server and 1 other directory.
by portal-commits@lists.jboss.org
Author: thomas.heute(a)jboss.com
Date: 2007-12-04 05:03:00 -0500 (Tue, 04 Dec 2007)
New Revision: 9270
Modified:
tags/JBoss_Portal_2_6_3/build/distrib.xml
tags/JBoss_Portal_2_6_3/server/src/main/org/jboss/portal/server/PortalConstants.java
Log:
Changing version to 2.6.3.GA
Modified: tags/JBoss_Portal_2_6_3/build/distrib.xml
===================================================================
--- tags/JBoss_Portal_2_6_3/build/distrib.xml 2007-12-04 09:57:56 UTC (rev 9269)
+++ tags/JBoss_Portal_2_6_3/build/distrib.xml 2007-12-04 10:03:00 UTC (rev 9270)
@@ -2,7 +2,7 @@
<property name="source.dir" value="../../jboss-portal-2.6"/>
<property name="docs.dir" value="${source.dir}-docs"/>
- <property name="release.version" value="2.6.3.SNAPSHOT"/>
+ <property name="release.version" value="2.6.3"/>
<!-- -->
<property name="portal.release.normal.name" value="jboss-portal-${release.version}"/>
Modified: tags/JBoss_Portal_2_6_3/server/src/main/org/jboss/portal/server/PortalConstants.java
===================================================================
--- tags/JBoss_Portal_2_6_3/server/src/main/org/jboss/portal/server/PortalConstants.java 2007-12-04 09:57:56 UTC (rev 9269)
+++ tags/JBoss_Portal_2_6_3/server/src/main/org/jboss/portal/server/PortalConstants.java 2007-12-04 10:03:00 UTC (rev 9270)
@@ -36,7 +36,7 @@
{
/** Current version. */
- public static final Version VERSION = new Version("JBoss Portal", 2, 6, 3, new Version.Qualifier(Version.Qualifier.Prefix.SNAPSHOT), "Ninja");
+ public static final Version VERSION = new Version("JBoss Portal", 2, 6, 3, new Version.Qualifier(Version.Qualifier.Prefix.GA), "Ninja");
/** The default portal name. */
public static final String DEFAULT_PORTAL_NAME = "default";
18 years, 7 months
JBoss Portal SVN: r9269 - tags.
by portal-commits@lists.jboss.org
Author: thomas.heute(a)jboss.com
Date: 2007-12-04 04:57:56 -0500 (Tue, 04 Dec 2007)
New Revision: 9269
Added:
tags/JBoss_Portal_2_6_3/
Log:
Tagging 2.6.3
Copied: tags/JBoss_Portal_2_6_3 (from rev 9268, branches/JBoss_Portal_Branch_2_6)
18 years, 7 months
JBoss Portal SVN: r9268 - branches/JBoss_Portal_Branch_2_6/core-admin/src/resources/portal-admin-war/WEB-INF/jsf.
by portal-commits@lists.jboss.org
Author: emuckenhuber
Date: 2007-12-04 04:53:44 -0500 (Tue, 04 Dec 2007)
New Revision: 9268
Modified:
branches/JBoss_Portal_Branch_2_6/core-admin/src/resources/portal-admin-war/WEB-INF/jsf/objectTemplate.xhtml
Log:
align pathitem in objectTemplate with object objectNavigation
Modified: branches/JBoss_Portal_Branch_2_6/core-admin/src/resources/portal-admin-war/WEB-INF/jsf/objectTemplate.xhtml
===================================================================
--- branches/JBoss_Portal_Branch_2_6/core-admin/src/resources/portal-admin-war/WEB-INF/jsf/objectTemplate.xhtml 2007-12-04 03:18:51 UTC (rev 9267)
+++ branches/JBoss_Portal_Branch_2_6/core-admin/src/resources/portal-admin-war/WEB-INF/jsf/objectTemplate.xhtml 2007-12-04 09:53:44 UTC (rev 9268)
@@ -3,6 +3,7 @@
xmlns:h="http://java.sun.com/jsf/html"
xmlns:ui="http://java.sun.com/jsf/facelets"
xmlns:f="http://java.sun.com/jsf/core"
+ xmlns:fn="http://java.sun.com/jsp/jstl/functions"
xmlns:c="http://java.sun.com/jstl/core"
class="admin-ui">
@@ -31,6 +32,14 @@
<li class="pathSeparator"><h:graphicImage url="/img/pathSeparator.png" alt=">"/></li>
</c:if>
<li class="#{node.id == portalobjectmgr.selectedObject.id ? 'selected' : 'pathItem'}">
+ <c:choose>
+ <c:when test="#{fn:startsWith(node.declaredProperties['portal.windowContentType'], 'widget/')}">
+ <!-- If window is of contentType widget -->
+ <h:panelGroup rendered="#{fn:startsWith(node.declaredProperties['portal.windowContentType'], 'widget/')}">
+ <span class="objectName">#{node.name}</span> #{node.typeName}
+ </h:panelGroup>
+ </c:when>
+ <c:otherwise>
<h:commandLink action="#{portalobjectmgr.selectObject}">
<f:param name="id" value="#{node.id}"/>
<c:choose>
@@ -38,6 +47,8 @@
<c:otherwise><span class="objectName">#{node.name}</span> #{node.typeName}</c:otherwise>
</c:choose>
</h:commandLink>
+ </c:otherwise>
+ </c:choose>
<h:outputText value=" #{portalObjectScreen}"
rendered="#{portalObjectScreen != null and node.id == portalobjectmgr.selectedObject.id}"/>
</li>
18 years, 7 months
JBoss Portal SVN: r9267 - in docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en: modules and 1 other directory.
by portal-commits@lists.jboss.org
Author: chris.laprun(a)jboss.com
Date: 2007-12-03 22:18:51 -0500 (Mon, 03 Dec 2007)
New Revision: 9267
Added:
docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/images/wsrp/config_self.png
Removed:
docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/images/wsrp/config_created.png
Modified:
docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/images/wsrp/bea.png
docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/images/wsrp/config_create.png
docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/images/wsrp/config_end.png
docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/images/wsrp/config_init.png
docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/images/wsrp/config_refresh.png
docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/images/wsrp/config_usewsdl.png
docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/images/wsrp/portlets.png
docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/modules/wsrp.xml
Log:
- Minor content improvements.
- Updated screenshots.
Modified: docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/images/wsrp/bea.png
===================================================================
(Binary files differ)
Modified: docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/images/wsrp/config_create.png
===================================================================
(Binary files differ)
Deleted: docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/images/wsrp/config_created.png
===================================================================
(Binary files differ)
Modified: docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/images/wsrp/config_end.png
===================================================================
(Binary files differ)
Modified: docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/images/wsrp/config_init.png
===================================================================
(Binary files differ)
Modified: docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/images/wsrp/config_refresh.png
===================================================================
(Binary files differ)
Added: docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/images/wsrp/config_self.png
===================================================================
(Binary files differ)
Property changes on: docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/images/wsrp/config_self.png
___________________________________________________________________
Name: svn:mime-type
+ image/png
Modified: docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/images/wsrp/config_usewsdl.png
===================================================================
(Binary files differ)
Modified: docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/images/wsrp/portlets.png
===================================================================
(Binary files differ)
Modified: docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/modules/wsrp.xml
===================================================================
--- docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/modules/wsrp.xml 2007-12-04 03:05:02 UTC (rev 9266)
+++ docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/modules/wsrp.xml 2007-12-04 03:18:51 UTC (rev 9267)
@@ -219,8 +219,8 @@
<para>
Let's work through the steps of defining access to a remote producer so that its portlets can be
consumed within JBoss Portal. We will configure access to BEA's public WSRP producer. We will first examine
- how to do so using an XML descriptor then see how the same can be accomplished using the configuration
- portlet.
+ how to do so using the configuration portlet. We will then show how the same result can be accomplish with
+ a producer descriptor.
</para>
<sect3 id="consumer_gui">
@@ -253,13 +253,8 @@
<imagedata fileref="images/wsrp/config_create.png" format="png" align="center" valign="middle"/>
</imageobject>
</mediaobject>
- You should now see a form allowing you to enter/modify the information about the Consumer:
- <mediaobject>
- <imageobject>
- <imagedata fileref="images/wsrp/config_created.png" format="png" align="center" valign="middle"/>
- </imageobject>
- </mediaobject>
- Set the cache expiration value to 120 seconds and enter the WSDL URL for the producer in the text field
+ You should now see a form allowing you to enter/modify the information about the Consumer.
+ Set the cache expiration value to 300 seconds and enter the WSDL URL for the producer in the text field
and press the "Save & Refresh" button:
<mediaobject>
<imageobject>
@@ -276,7 +271,9 @@
</imageobject>
</mediaobject>
<note>At this point, there is no automated way to learn about which possible values (if any) are
- expected by the remote Producer. Please refer to the specific Producer's documentation.</note>
+ expected by the remote Producer. In the case of BEA's public producer, the possible values are
+ indicated in the registration property description. This is not always the case... Please refer to
+ the specific Producer's documentation.</note>
Enter "public" as the value for the registration property and press "Save & Refresh" once more. You should now
see something similar to:
<mediaobject>
@@ -310,7 +307,7 @@
"http://www.jboss.org/portal/dtd/jboss-wsrp-consumer_2_6.dtd">
<deployments>
<deployment>
- <wsrp-producer id="bea" expiration-cache="120">
+ <wsrp-producer id="bea" expiration-cache="300">
<endpoint-wsdl-url>http://wsrp.bea.com:7001/producer/producer?WSDL</endpoint-wsdl-url>
<registration-data>
<property>
18 years, 7 months
--- branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIContextImpl.java 2007-12-04 10:59:39 UTC (rev 9273)
+++ branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIContextImpl.java 2007-12-04 10:59:41 UTC (rev 9274)
@@ -63,11 +63,20 @@
{
public void update(StructuralObject object)
{
- // Get the corresping object
+ // Get the corresponding object
UIObjectImpl tmp = objects.get(object.getId());
- // Update its structural view
- tmp.structuralObject = object;
+ // If it is not here, create it
+ if (tmp == null)
+ {
+ tmp = createObject(object);
+ objects.put(object.getId(), tmp);
+ }
+ else
+ {
+ // Update its structural view
+ tmp.update(object);
+ }
}
public void remove(String id)
@@ -81,9 +90,7 @@
return loader.load(loader.getRootId());
}
- public UIContextImpl(
- StructuralStateContext structuralStateContext,
- NavigationalStateContext navigationalStateContext)
+ public UIContextImpl(StructuralStateContext structuralStateContext, NavigationalStateContext navigationalStateContext)
{
super(getRootState(structuralStateContext));
@@ -101,16 +108,34 @@
*/
public UIObject getObject(String id)
{
+ return getFromUniverse(id, true);
+ }
+
+ UIObject getFromUniverse(String id, boolean loadIfAbsent)
+ {
try
{
UIObject object = objects.get(id);
- if (object == null)
+
+ //
+ if (object != null)
{
+ return object;
+ }
+
+ //
+ if (loadIfAbsent)
+ {
//Fetch the state of the UIObject in question
StructuralObject structuralObject = this.structuralStateContext.load(id);
- return loadObject(structuralObject);
+
+ //
+ return updateUniverse(structuralObject);
}
- return object;
+ else
+ {
+ throw new AssertionError("Should not be here");
+ }
}
catch (Exception e)
{
@@ -118,6 +143,23 @@
}
}
+ protected UIObjectImpl updateUniverse(StructuralObject structuralObject)
+ {
+ UIObjectImpl object = objects.get(structuralObject.getId());
+
+ //
+ if (object == null)
+ {
+ object = createObject(structuralObject);
+
+ //
+ objects.put(structuralObject.getId(), object);
+ }
+
+ //
+ return object;
+ }
+
public void addModelListener(ModelListener listener)
{
if (listener == null)
@@ -132,19 +174,8 @@
}
}
- protected UIObjectImpl loadObject(StructuralObject structuralObject)
+ private UIObjectImpl createObject(StructuralObject state)
{
- UIObjectImpl object = objects.get(structuralObject.getId());
- if (object == null)
- {
- object = getImplementation(structuralObject);
- objects.put(structuralObject.getId(), object);
- }
- return object;
- }
-
- private UIObjectImpl getImplementation(StructuralObject state)
- {
Class type = state.getState().getType();
if(type == UIPortal.class)
{
Modified: branches/presentation/presentation/src/main/org/jboss/portal/presentation/impl/model/UIObjectImpl.java
===================================================================